@@ -56,6 +56,7 @@ public:
     virtual int indexOfObject(QObject *object) const = 0;
 
 signals:
+    void aboutToBeAdded(int index);
     void added(int index);
     void aboutToBeRemoved(int index);
     void removed(int index);
@@ -111,10 +112,17 @@ public:
     {
         Q_ASSERT(!m_data.contains(object->index()));
 
-        m_data.insert(object->index(), object);
+        int modelIndex = 0;
+        for (auto it = m_data.constBegin(); it != m_data.constEnd(); ++it) {
+            if (object->index() < it.key()) {
+                break;
+            }
+            modelIndex++;
+        }
 
-        const int modelIndex = m_data.keys().indexOf(object->index());
-        Q_ASSERT(modelIndex >= 0);
+        emit aboutToBeAdded(modelIndex);
+        m_data.insert(object->index(), object);
+        Q_ASSERT(modelIndex == m_data.keys().indexOf(object->index()));
         emit added(modelIndex);
     }
 
@@ -130,19 +138,14 @@ public:
             return;
         }
 
-        const bool isNew = !m_data.contains(info->index);
-
         auto *obj = m_data.value(info->index, nullptr);
         if (!obj) {
             obj = new Type(parent);
         }
         obj->update(info);
-        m_data.insert(info->index, obj);
 
-        if (isNew) {
-            const int modelIndex = m_data.keys().indexOf(info->index);
-            Q_ASSERT(modelIndex >= 0);
-            emit added(modelIndex);
+        if (!m_data.contains(info->index)) {
+            insert(obj);
         }
     }
 
